pub enum Error {
Backend(Error),
MissingCharacteristic(Characteristic),
NotificationStreamEnded,
NotificationTooLong {
actual: usize,
capacity: usize,
},
UnexpectedNotificationCharacteristic(Uuid),
}Expand description
Errors from the optional btleplug transport adapter.
Variants
Backend(Error)
The underlying btleplug backend returned an error.
MissingCharacteristic(Characteristic)
Service discovery did not expose a required Move characteristic.
NotificationStreamEnded
The peripheral-wide notification stream ended.
NotificationTooLong
A received notification cannot fit in the session buffer.
Fields
UnexpectedNotificationCharacteristic(Uuid)
A notification came from a characteristic not used by this protocol.